@@ -4,7 +4,7 @@ use warnings;
 
 {
     no strict "vars";
-    $VERSION = "1.07";
+    $VERSION = "1.08";
 }
 
 use Acme::CPANAuthors::Register (
@@ -28,6 +28,7 @@ use Acme::CPANAuthors::Register (
     'MIYAGAWA'      => 'Tatsuhiko Miyagawa',
     'MLEHMANN'      => 'Marc Lehmann',
     'MRAMBERG'      => 'Marcus Ramberg',
+    'NEILB'         => 'Neil Bowers',
     'NUFFIN'        => 'Yuval Kogman',
     'PERLANCAR'     => 'perlancar',
     'PEVANS'        => 'Paul Evans',
@@ -73,40 +74,41 @@ currently maintaining 100 or more distributions on CPAN.
 
 =head1 THE AUTHORS
 
-   1.  280  PERLANCAR     perlancar
-   2.  276  RJBS          Ricardo SIGNES
+   1.  318  PERLANCAR     perlancar
+   2.  278  RJBS          Ricardo SIGNES
    3.  266  TOBYINK       Toby Inkster
    4.  248  ADAMK         Adam Kennedy
-   5.  224  MIYAGAWA      Tatsuhiko Miyagawa
-   6.  209  FLORA         Florian Ragwitz
-   7.  209  INGY          Ingy dot Net
-   8.  209  SHARYANTO     Steven Haryanto
-   9.  208  BINGOS        Chris Williams
+   5.  226  MIYAGAWA      Tatsuhiko Miyagawa
+   6.  212  INGY          Ingy dot Net
+   7.  209  FLORA         Florian Ragwitz
+   8.  208  BINGOS        Chris Williams
+   9.  195  SHARYANTO     Steven Haryanto
   10.  183  SMUELLER      Steffen Mueller
   11.  181  TOKUHIROM     Tokuhiro Matsuno
-  12.  171  DAGOLDEN      David Golden
-  13.  165  ETHER         Karen Etheridge
+  12.  172  DAGOLDEN      David Golden
+  13.  168  ETHER         Karen Etheridge
   14.  158  NUFFIN        Yuval Kogman
-  15.  157  MARCEL        Marcel Gruenauer
-  16.  155  KENTNL        Kent Fredric
+  15.  157  KENTNL        Kent Fredric
+  16.  157  MARCEL        Marcel Gruenauer
   17.  152  BOBTFISH      Tomas Doran
   18.  132  DROLSKY       Dave Rolsky
-  19.  126  PEVANS        Paul Evans
+  19.  127  PEVANS        Paul Evans
   20.  123  DMAKI         Daisuke Maki
   21.  122  GUGOD         Liu Kang Min
   22.  118  SIMON         Simon Cozens
-  23.  113  BARBIE        Barbie
-  24.  112  AUTRIJUS      Audrey Tang
-  25.  106  SHLOMIF       Shlomi Fish
-  26.  104  SALVA         Salvador Fandino Garcia
-  27.  103  SKIM          Michal Spacek
-  28.  102  BDFOY         brian d foy
-  29.  102  LBROCARD      Leon Brocard
-  30.  102  RSAVAGE       Ron Savage
+  23.  115  BARBIE        Barbie
+  24.  114  SKIM          Michal Spacek
+  25.  112  AUTRIJUS      Audrey Tang
+  26.  107  RSAVAGE       Ron Savage
+  27.  107  SHLOMIF       Shlomi Fish
+  28.  104  SALVA         Salvador Fandino Garcia
+  29.  103  BDFOY         brian d foy
+  30.  102  LBROCARD      Leon Brocard
   31.  101  MRAMBERG      Marcus Ramberg
   32.  100  MLEHMANN      Marc Lehmann
+  33.  100  NEILB         Neil Bowers
 
-List last updated: 2015-01-24T17:56:48
+List last updated: 2015-03-22T11:39:41
 
 =head1 MAINTENANCE
 
